#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 validation-selective
version:              0.1.0.0
visibility:           public
id:                   validation-selective-0.1.0.0-6VrI4GKYO0T3qfVEN7Ei1u
key:                  validation-selective-0.1.0.0-6VrI4GKYO0T3qfVEN7Ei1u
license:              MPL-2.0
copyright:            2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov, Veronika Romashkina
homepage:             https://github.com/kowainik/validation-selective
synopsis:
    Lighweight pure data validation based on Applicative and Selective functors

description:
    Lighweight pure data validation based on Applicative and Selective
    functors. The library builds validation interface around the
    following data type:

    @
    __data__ Validation e a
    \    = Failure e
    \    | Success a
    @

category:             Validation, Selective, Data
abi:                  02303ff9a36de60e036eb29c335f44ce
exposed:              True
exposed-modules:      Validation Validation.Combinators
import-dirs:          /usr/lib/ghc-8.10.3/site-local/validation-selective-0.1.0.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/validation-selective-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.3/validation-selective-0.1.0.0

hs-libraries:         HSvalidation-selective-0.1.0.0-6VrI4GKYO0T3qfVEN7Ei1u
depends:
    base-4.14.1.0 deepseq-1.4.4.0
    selective-0.4.1.1-KVYVSIMNOB3Lgg8KiTMfXa

haddock-interfaces:
    /usr/share/doc/haskell-validation-selective/html/validation-selective.haddock

haddock-html:         /usr/share/doc/haskell-validation-selective/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

